@@ -437,6 +437,7 @@ void usage_wifi(FILE* out)
 {
 	fprintf(out, "%s %s wifi [--swap] power [1/0]\n", usage_lead(), argv0);
 	fprintf(out, "%s %s wifi maxperf <iface> [1/0]\n", usage_lead(), argv0);
+	fprintf(out, "%s %s wifi keep-bus-on-in-suspend [1/0]\n", usage_lead(), argv0);
 }
 
 int do_wifi(int argc, char *const *argv)
@@ -497,6 +498,27 @@ int do_wifi(int argc, char *const *argv)
 			usage_wifi(stderr);
 			return 1;
 		}
+	} else if (strcmp(argv[1], "keep-bus-on-in-suspend") == 0) {
+		if (argc == 2)
+		{
+			int res = om_wifi_keep_bus_on_in_suspend_get();
+			if (res < 0)
+			{
+				perror("reading WiFi keep-bus-on-in-suspend");
+				return 1;
+			}
+			printf("%d\n", res);
+		} else if (argc == 3) {
+			int res = om_wifi_keep_bus_on_in_suspend_set(atoi(argv[2]));
+			if (res < 0)
+			{
+				perror("setting WiFi keep-bus-on-in-suspend");
+				return 1;
+			}
+		} else {
+			usage_wifi(stderr);
+			return 1;
+		}
 	} else {
 		usage_wifi(stderr);
 		return 1;
@@ -944,9 +966,9 @@ int do_version(int argc, char *const *argv)
 void usage_options(FILE* out)
 {
 	fprintf(out, "Options:\n");
-	fprintf(out, "  --help:    print this help message\n");
-	fprintf(out, "  --version: print version and exit\n");
-	fprintf(out, "  --swap:    set new value and print old value\n");
+	fprintf(out, "  --help\tprint this help message\n");
+	fprintf(out, "  --version\tprint version and exit\n");
+	fprintf(out, "  --swap\tset new value and print old value\n");
 }
 
 int parse_options(int argc, char *const *argv)
